// Tulsa Sample AppView.cpp : implementation of the CTulsaSampleAppView class
//

#include "stdafx.h"
#include "Tulsa Sample App.h"
#include "mainfrm.h"
#include "Tulsa Sample AppDoc.h"
#include "Tulsa Sample AppView.h"
#include "CardDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CTulsaSampleAppView

IMPLEMENT_DYNCREATE(CTulsaSampleAppView, CView)

BEGIN_MESSAGE_MAP(CTulsaSampleAppView, CView)
	//{{AFX_MSG_MAP(CTulsaSampleAppView)
	ON_WM_TIMER()
	ON_WM_LBUTTONDOWN()
	//}}AFX_MSG_MAP
	// Standard printing commands
	ON_COMMAND(ID_FILE_PRINT, CView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_DIRECT, CView::OnFilePrint)
	ON_COMMAND(ID_FILE_PRINT_PREVIEW, CView::OnFilePrintPreview)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CTulsaSampleAppView construction/destruction

CTulsaSampleAppView::CTulsaSampleAppView()
{
	m_pPropertySheet = NULL;
	for (int i = 0; i < MAX_STB_TULSA_CARDS; i++) {
		m_pPropertyPage[i] = NULL;
	}
}

CTulsaSampleAppView::~CTulsaSampleAppView()
{
	if (m_pPropertySheet) {
		delete m_pPropertySheet;
		m_pPropertySheet = NULL;
	}
	for (int i = 0; i < MAX_STB_TULSA_CARDS; i++) {
		if (m_pPropertyPage[i]) {
			delete m_pPropertyPage[i];
			m_pPropertyPage[i] = NULL;
		}
	}
}


/////////////////////////////////////////////////////////////////////////////
// CTulsaSampleAppView drawing
/////////////////////////////////////////////////////////////////////////////
void CTulsaSampleAppView::OnDraw(CDC* pDC)
{
	CTulsaSampleAppDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);

	// TODO: add draw code for native data here
}


/////////////////////////////////////////////////////////////////////////////
// CTulsaSampleAppView diagnostics
/////////////////////////////////////////////////////////////////////////////
#ifdef _DEBUG
void CTulsaSampleAppView::AssertValid() const
{
	CView::AssertValid();
}

void CTulsaSampleAppView::Dump(CDumpContext& dc) const
{
	CView::Dump(dc);
}

CTulsaSampleAppDoc* CTulsaSampleAppView::GetDocument() // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(CTulsaSampleAppDoc)));
	return (CTulsaSampleAppDoc*)m_pDocument;
}
#endif //_DEBUG


int CTulsaSampleAppView::GetCurrentCard()
{
	if (m_pPropertySheet) {
		return m_pPropertySheet->GetActiveIndex();
	}
	return(0);
}

/////////////////////////////////////////////////////////////////////////////
// CTulsaSampleAppView message handlers

PSZ pszCard[MAX_STB_TULSA_CARDS] = {"Card 0", "Card 1", "Card 2", "Card 3"};

void CTulsaSampleAppView::OnInitialUpdate() 
{
	HRESULT result;
	ISTBTBoardControl *pBoardControl;
	LPDIRECTDRAW lpDirectDrawYUV = NULL;
	LPDIRECTDRAW lpDirectDrawRGB = NULL;
	char szStr[150];
	int NumPages = 0;

	CView::OnInitialUpdate();

	m_pPropertySheet = new CPropertySheet("", this, 0);

	for (int i = 0, j = 0; i < MAX_STB_TULSA_CARDS; i++) {
		if (tcGuids[i].Data1) {
												// Create the Control Object for the board
			result = CoCreateInstance(tcGuids[i], NULL, CLSCTX_INPROC, IID_ISTBTBoardControl, (LPVOID *)&pBoardControl);
			if (result != SUCCESS) {
				sprintf(szStr, "Could not create a Control Object for card %d.", i);
				AfxMessageBox(szStr);
				continue;
			}
												// Create the DDEmulation Object for the RGB Processor
			result = CoCreateInstance(ddeGuids.RGBProcGuids[i], NULL, CLSCTX_INPROC, IID_IDirectDraw, (LPVOID *)&lpDirectDrawRGB);
			if (result != SUCCESS) {
				sprintf(szStr, "Could not create a DD Emulation Object (RGB Proc) for card %d.", i);
				AfxMessageBox(szStr);
				pBoardControl->Release();
				pBoardControl = NULL;
				continue;
			} 
												// Create the DDEmulation Object for the YUV Processor
			result = CoCreateInstance(ddeGuids.YUVProcGuids[i], NULL, CLSCTX_INPROC, IID_IDirectDraw, (LPVOID *)&lpDirectDrawYUV);
			if (result != SUCCESS) {
				sprintf(szStr, "Could not create a DD Emulation Object (YUV Proc) for card %d.", i);
				AfxMessageBox(szStr);
				pBoardControl->Release();
				pBoardControl = NULL;
				continue;
			} 
			m_pPropertyPage[j] = new CCardDlg(i);
			m_pPropertyPage[j]->pBoardControl = pBoardControl;
			m_pPropertyPage[j]->lpDirectDrawRGB = lpDirectDrawRGB;
			m_pPropertyPage[j]->lpDirectDrawYUV = lpDirectDrawYUV;
			m_pPropertyPage[j]->m_psp.dwFlags |= PSP_USETITLE;
			m_pPropertyPage[j]->m_psp.pszTitle = pszCard[i];
			m_pPropertySheet->AddPage(m_pPropertyPage[j]);
			NumPages++;
		}
	}

	if (NumPages == 0) {
		delete m_pPropertySheet;
		m_pPropertySheet = NULL;
		AfxGetMainWnd()->PostMessage(WM_CLOSE);
		return;
	}

	m_pPropertySheet->Create(this, WS_CHILD | WS_VISIBLE);
	m_pPropertySheet->SetWindowPos(NULL, 0, 0, 0, 0, SWP_NOSIZE | SWP_NOZORDER);
  
	RECT rect;
	m_pPropertySheet->GetClientRect(&rect);
	CFrameWnd* pParent = GetParentFrame();
	if (pParent) {
		pParent->SetWindowPos(NULL, 0, 0, rect.right + 1, rect.bottom + 1, SWP_NOMOVE | SWP_NOZORDER);
	}

	m_pPropertySheet->SetActivePage(0);

}


BOOL CTulsaSampleAppView::DestroyWindow() 
{
	m_pPropertySheet->DestroyWindow();
	return CView::DestroyWindow();
}


CCardDlg* CTulsaSampleAppView::GetActiveCardDialog()
{
	return (CCardDlg*)m_pPropertySheet->GetActivePage();
}

void CTulsaSampleAppView::SetActiveCardDialog(int page)
{
	m_pPropertySheet->SetActivePage(page);
}


void CTulsaSampleAppView::SetActiveNextCardDialog()
{
	int NumPages = m_pPropertySheet->GetPageCount();
	int page = m_pPropertySheet->GetActiveIndex();
	if (++page >= NumPages) {
		page = 0;
	}
	m_pPropertySheet->SetActivePage(page);
}


CCardDlg* CTulsaSampleAppView::GetCardDialog(int card)
{
	return (CCardDlg*)m_pPropertyPage[card];
}


